@@ -36,18 +36,9 @@ def prompt_directly():
     pyperclip.copy(command.strip())
     print(f"{command}")
     print("The command has been copied to the clipboard")
-    
 
 
-    
-    
-        
 
-    
-
-
-if __name__ == "__main__":
-    main()
 
     
     
